@@ -13,11 +13,8 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-from typing import NewType, Callable
 
 PROJECT_NAME = "OctoBot-Channels"
-VERSION = "1.0.9"  # major.minor.revision
-
-CONSUMER_CALLBACK_TYPE = NewType('CallbackType', Callable[..., None])
+VERSION = "1.3.9"  # major.minor.revision
 
 CHANNEL_WILDCARD = "*"
