@@ -18,6 +18,10 @@ import asyncio
 
 from octobot_commons.logging.logging_util import get_logger
 
+"""
+A channel Producer
+"""
+
 
 class Producer:
     def __init__(self, channel):
@@ -26,9 +30,6 @@ class Producer:
         # Related channel instance
         self.channel = channel
 
-        # List of subscribed consumers
-        self.consumers = []
-
         """
         Should only be used with .cancel()
         """
@@ -41,16 +42,25 @@ class Producer:
         """
         self.should_stop = False
 
-    async def send(self, **kwargs):
+    async def send(self, data, **kwargs) -> None:
         """
         Send to each consumer data though its queue
+        :param data: data to be put into consumers queues
         :param kwargs:
         :return: None
         """
-        for consumer in self.consumers:
-            await consumer.queue.put(kwargs)
+        """
+        The implementation should use 'self.channel.get_consumers'
+        Example
+            for consumer in self.channel.get_consumers():
+                await consumer.queue.put({
+                    "my_key": my_key_value
+                })
+        """
+        for consumer in self.channel.get_consumers():
+            await consumer.queue.put(data)
 
-    async def push(self, **kwargs):
+    async def push(self, **kwargs) -> None:
         """
         Push notification that new data should be sent implementation
         When nothing should be done on data : self.send()
@@ -58,14 +68,28 @@ class Producer:
         """
         pass
 
-    async def start(self):
+    async def start(self) -> None:
         """
         Should be implemented for producer's non-triggered tasks
         :return: None
         """
         pass
 
-    async def perform(self, **kwargs):
+    async def pause(self) -> None:
+        """
+        Called when the channel runs out of consumer
+        :return: None
+        """
+        pass
+
+    async def resume(self) -> None:
+        """
+        Called when the channel is no longer out of consumer
+        :return: None
+        """
+        pass
+
+    async def perform(self, **kwargs) -> None:
         """
         Should implement producer's non-triggered tasks
         Can be use to force producer to perform tasks
@@ -73,31 +97,42 @@ class Producer:
         """
         pass
 
-    async def modify(self, **kwargs):
+    async def modify(self, **kwargs) -> None:
         """
         Should be implemented when producer can be modified during perform()
         :return: None
         """
         pass
 
+    async def wait_for_processing(self) -> None:
+        """
+        Should be used only with SupervisedConsumers
+        It will wait until all consumers have notified that their consume() method have ended
+        :return: None
+        """
+        await asyncio.gather(*[consumer.queue.join() for consumer in self.channel.get_consumers()])
+
     async def stop(self):
         """
         Stops non-triggered tasks management
         :return: None
         """
         self.should_stop = True
+        if self.produce_task:
+            self.produce_task.cancel()
 
-    def create_task(self):
+    def create_task(self) -> None:
         """
         Creates a new asyncio task that contains start() execution
         :return: None
         """
         self.produce_task = asyncio.create_task(self.start())
 
-    async def run(self):
+    async def run(self) -> None:
         """
         Start the producer main task
+        Should call 'self.channel.register_producer'
         :return: None
         """
-        self.channel.register_producer(self)
+        await self.channel.register_producer(self)
         self.create_task()
