@@ -15,12 +15,12 @@
 #  License along with this library.
 
 
-async def create_all_subclasses_channel(channel_class, channels_class, **kwargs):
+async def create_all_subclasses_channel(channel_class, set_chan_method, **kwargs):
     for to_be_created_channel_class in channel_class.__subclasses__():
-        await create_channel_instance(to_be_created_channel_class, channels_class, **kwargs)
+        await create_channel_instance(to_be_created_channel_class, set_chan_method, **kwargs)
 
 
-async def create_channel_instance(channel_class, channels_class, **kwargs):
+async def create_channel_instance(channel_class, set_chan_method, **kwargs):
     created_channel = channel_class(**kwargs)
-    channels_class.set_chan(created_channel, name=channel_class.get_name())
+    set_chan_method(created_channel, name=channel_class.get_name())
     await created_channel.start()
